#Link CPs - Surface Variables (Iberian Peninsula and Catalunya)
#Plotting spatial patterns (anom)
library(ncdf4)
library(ggplot2)
library(gridExtra)
library(fields)
library(mapdata)
#library(matrixStats)
#library(metR)
library(RColorBrewer)

rm(list=ls()) ; gc()

#Directory information
setwd("../../../scratch/")
OUTPUTS <- "/esarchive/scratch/molmo/SpatialPatterns_AEMET-5km/"

#Useful functions
png.save <- function(x,filename,main,xlab,ylab){
  png(filename = paste(filename,".png",sep=""))
  plot(x,type="o",main=main,xlab = xlab,ylab=ylab)
  dev.off()
}

seasons <- list("Summer"=c("06","07","08"),"Winter"=c("12","01","02"),
                "Spring"=c("03","04","05"),"Autumn"=c("09","10","11"))

dom="D4"
for(k in c(4,8)){
  message(k)
for(sn in 1:4){
  message(names(seasons)[sn])
  #######################---tasmax---####################################
  #Łoad observational data
load(paste("SpatialPatterns_Ward_Surface_TX_Anom_D4_Iberia_",k,"_",names(seasons)[sn],"_AEMET-5km_CPs.Rdata",sep=""))
  
  p <- ggplot(datitos,aes(x=Longitude,y=Latitude))  + geom_tile(aes(fill=Z))  + borders(colour = "grey22",size=0.3) + facet_wrap(~CP,nrow=1)+ 
    scale_fill_gradientn(name=expression("TX (ºC)"),breaks=seq(-5,5,by=2),limits=c(-5,5),
                         colours=rev(brewer.pal(9,"RdBu")),aesthetics=c("fill"),
                         na.value = "white") +
    coord_quickmap(xlim=c(min(datitos$Longitude),max(datitos$Longitude)),ylim=c(min(datitos$Latitude),max(datitos$Latitude)),expand = F) +
    xlab("Longitude") + ylab("Latitude") + theme_bw() + ggtitle(names(seasons)[sn])
  ggsave(p,filename=paste(OUTPUTS,"SpatialPatterns_Ward_Surface_TX_Anom_",dom,"_Iberia_",k,"_",names(seasons)[sn],"CPs.png",sep=""),device="png",
         dpi=600,width=2*k,height = 6)
  
  ####################################################################################
  #######################---tasmin---####################################
  load(paste("SpatialPatterns_Ward_Surface_TN_Anom_D4_Iberia_",k,"_",names(seasons)[sn],"_AEMET-5km_CPs.Rdata",sep=""))
  
  p <- ggplot(datitos,aes(x=Longitude,y=Latitude))  + geom_tile(aes(fill=Z))  + borders(colour = "grey22",size=0.3) + facet_wrap(~CP,nrow=1)+ 
    scale_fill_gradientn(name=expression("TN (ºC)"),breaks=seq(-5,5,by=2),limits=c(-5,5),
                         colours=rev(brewer.pal(9,"RdBu")),aesthetics=c("fill"),
                         na.value = "white") +
    coord_quickmap(xlim=c(min(datitos$Longitude),max(datitos$Longitude)),ylim=c(min(datitos$Latitude),max(datitos$Latitude)),expand = F) +
    xlab("Longitude") + ylab("Latitude") + theme_bw() + ggtitle(names(seasons)[sn]) 
  ggsave(p,filename=paste(OUTPUTS,"SpatialPatterns_Ward_Surface_TN_Anom_",dom,"_Iberia_",k,"_",names(seasons)[sn],"CPs.png",sep=""),device="png",
         dpi=600,width=2*k,height = 6)
  
  #################---precip---##############################################
  load(paste("SpatialPatterns_Ward_Surface_PR_Anom_D4_Iberia_",k,"_",names(seasons)[sn],"_AEMET-5km_CPs.Rdata",sep=""))
  
  p <- ggplot(datitos,aes(x=Longitude,y=Latitude))  + geom_tile(aes(fill=Z))  + borders(colour = "grey22",size=0.3) + facet_wrap(~CP,nrow=1)+ 
    scale_fill_gradientn(name=expression("PR (mm)"),breaks=seq(-5,5,by=2),limits=c(-5,5),
                         colours=brewer.pal(9,"BrBG"),aesthetics=c("fill"),
                         na.value = "white") +
    coord_quickmap(xlim=c(min(datitos$Longitude),max(datitos$Longitude)),ylim=c(min(datitos$Latitude),max(datitos$Latitude)),expand = F) +
    xlab("Longitude") + ylab("Latitude") + theme_bw() + ggtitle(names(seasons)[sn]) 
  ggsave(p,filename=paste(OUTPUTS,"SpatialPatterns_Ward_Surface_PR_Anom_",dom,"_Iberia_",k,"_",names(seasons)[sn],"CPs.png",sep=""),device="png",
         dpi=600,width=2*k,height = 6)
  
}
}
